// For description of these values see http://adblockplus.org/en/preferences

pref("extensions.adblockplus.currentVersion", "0.0");
pref("extensions.adblockplus.enabled", true);
pref("extensions.adblockplus.frameobjects", true);
pref("extensions.adblockplus.fastcollapse", false);
pref("extensions.adblockplus.showinstatusbar", false);
pref("extensions.adblockplus.detachsidebar", false);
pref("extensions.adblockplus.defaulttoolbaraction", 0);
pref("extensions.adblockplus.defaultstatusbaraction", 0);
pref("extensions.adblockplus.sidebar_key", "Accel Shift V");
pref("extensions.adblockplus.sendReport_key", "");
pref("extensions.adblockplus.filters_key", "Accel Shift E, Accel Shift F, Accel Shift O");
pref("extensions.adblockplus.enable_key", "");
pref("extensions.adblockplus.flash_scrolltoitem", true);
pref("extensions.adblockplus.previewimages", true);
pref("extensions.adblockplus.data_directory", "adblockplus");
pref("extensions.adblockplus.patternsbackups", 5);
pref("extensions.adblockplus.patternsbackupinterval", 24);
pref("extensions.adblockplus.whitelistschemes", "about chrome file irc moz-safe-about news resource snews x-jsd addbook cid imap mailbox nntp pop data javascript moz-icon");
pref("extensions.adblockplus.hideimagemanager", true);
pref("extensions.adblockplus.subscriptions_listurl", "https://adblockplus.org/subscriptions2.xml");
pref("extensions.adblockplus.subscriptions_fallbackurl", "https://adblockplus.org/getSubscription?version=%VERSION%&url=%SUBSCRIPTION%&downloadURL=%URL%&error=%ERROR%&channelStatus=%CHANNELSTATUS%&responseStatus=%RESPONSESTATUS%");
pref("extensions.adblockplus.subscriptions_fallbackerrors", 5);
pref("extensions.adblockplus.subscriptions_exceptionsurl", "https://easylist-downloads.adblockplus.org/exceptionrules.txt");
pref("extensions.adblockplus.subscriptions_exceptionscheckbox", true);
pref("extensions.adblockplus.documentation_link", "https://adblockplus.org/redirect?link=%LINK%&lang=%LANG%");
pref("extensions.adblockplus.savestats", true);
pref("extensions.adblockplus.composer_default", 2);
pref("extensions.adblockplus.clearStatsOnHistoryPurge", true);
pref("extensions.adblockplus.report_submiturl", "https://reports.adblockplus.org/submitReport?version=1&guid=%GUID%&lang=%LANG%");
pref("extensions.adblockplus.recentReports", "[]");
pref("services.sync.engine.adblockplus", false);
